AbstractMath
============

.. currentmodule:: pqp.symbols

.. autoclass:: AbstractMath
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~AbstractMath.display
      ~AbstractMath.to_latex

   .. rubric:: Methods Documentation

   .. automethod:: display
   .. automethod:: to_latex
